% sb_read           - Read out single-bunch data from iGp2
%
% prm = sb_read(device);
%
% Arguments:
%  device    - Device ID, presumes IGPF system base
%
% Outputs:
%  prm.freq     - Frequency axis
%  prm.mag      - Magnitude (gain or spectrum)
%  prm.phase    - Phase (valid only for transfer function mode)
%  prm.t        - Time scale (ms)
%  prm.data     - Bunch data vector
%  prm.samples  - Number of samples in the above two vectors
%  prm.bunch    - Bunch number
%  prm.nfft     - Window and FFT length
%  prm.noverlap - Overlap

%
% Copyright (c) 2013 Dimtel, Inc., All Rights Reserved
%
% $Id$
% $Date$
% $Author$
% $Revision$
% $Log$

function prm = sb_read(device);

pvnm = ['IGPF:', device, ':SB:'];

pvs = { 'FREQ'; 'MAG'; 'PHASE'; 'RAW'; 'TSC'; ...
        'RAW:SAMPLES'; 'RAW:BUNCH_ID'};

for k=1:length(pvs)
  pvs{k} = [pvnm, pvs{k}];
end

vals = lcaGet(pvs);

prm.freq     = vals(1,:);
prm.mag      = vals(2,:);
prm.phase    = vals(3,:);
prm.samples  = vals(6,1);
prm.data     = vals(4,1:prm.samples);
prm.t        = vals(5,1:prm.samples);
prm.bunch    = vals(7,1);
prm.nfft     = lcaGet([pvnm, 'NFFT']); prm.nfft = str2num(prm.nfft{1});
prm.noverlap = lcaGet([pvnm, 'NOVERLAP']); prm.noverlap = str2num(prm.noverlap{1});

% Get rid of empty values
u = isfinite(prm.freq);
prm.freq  = prm.freq(u);
prm.mag   = prm.mag(u);
prm.phase = prm.phase(u);
